@@ -6,7 +6,7 @@ from pynamodb.models import MetaModel
 from pynamodb.connection.util import pythonic
 
 def table_name(name):
-    return name + '_' + os.environ.get('AWS_ENV', 'local')
+    return name + '_' + os.environ.get('AWS_ENV', 'DEV').lower()
 
 def table_region():
     return os.environ.get('AWS_DEFAULT_REGION', 'ap-southeast-1')
