@@ -26,8 +26,24 @@ class AMaaSUserTest(unittest.TestCase):
         errors = user.check_asset_manager_permissions([101])
         self.assertTrue(len(errors) == 0)
 
-        errors = user.check_asset_manager_permissions([102])
+        errors = user.check_asset_manager_permissions(['101'])
+        self.assertTrue(len(errors) == 0)
+
+        errors = user.check_asset_manager_permissions([101,102])
         self.assertTrue(102 in errors)
+
+        with self.assertRaises(ValueError):
+            errors = user.check_asset_manager_permissions(['Invalid101'])
+        
+    @patch('amaasinfra.authorization.amaas_user.unpack_token')
+    @patch('amaasinfra.authorization.amaas_user.AssetManagerRelationship')
+    def testCheckNewUserPermissions(self, mock_relationship, mock_unpack_token):
+        mock_unpack_token.return_value = {TokenAttribute.username.value: 'new_user'}
+        user = AMaaSUser('')
+        
+        claims = [10, 11, 12, 101]
+        errors = user.check_asset_manager_permissions(claims)
+        self.assertEqual(claims, errors)
     
     def testLoadRelationships(self):
         pass
